mercurial/dispatch.py
changeset 37119 d4a2e0d5d042
parent 37084 f0b6fbea00cf
child 37120 a8a902d7176e
--- a/mercurial/dispatch.py	Sat Mar 24 13:38:04 2018 +0900
+++ b/mercurial/dispatch.py	Sat Mar 24 15:09:33 2018 +0900
@@ -42,6 +42,7 @@
 )
 
 from .utils import (
+    procutil,
     stringutil,
 )
 
@@ -127,8 +128,8 @@
                 pass
             # Otherwise mark it as closed to silence "Exception ignored in"
             # message emitted by the interpreter finalizer. Be careful to
             # not close util.stdout, which may be a fdopen-ed file object and
             # its close() actually closes the underlying file descriptor.
             try:
                 fp.close()
             except IOError:
@@ -180,7 +181,7 @@
     elif req.ui:
         ferr = req.ui.ferr
     else:
-        ferr = util.stderr
+        ferr = procutil.stderr
 
     try:
         if not req.ui:
@@ -127,8 +128,8 @@
             # Otherwise mark it as closed to silence "Exception ignored in"
             # message emitted by the interpreter finalizer. Be careful to
-            # not close util.stdout, which may be a fdopen-ed file object and
-            # its close() actually closes the underlying file descriptor.
+            # not close procutil.stdout, which may be a fdopen-ed file object
+            # and its close() actually closes the underlying file descriptor.
             try:
                 fp.close()